#
# spec file for package gnome-subtitles
#
# Copyright (c) 2013 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           gnome-subtitles
Version:        1.3
Release:        6.4
Summary:        Subtitle editor for GNOME
License:        GPL-2.0+
Group:          Productivity/Multimedia/Video/Editors and Convertors
Url:            http://gnome-subtitles.sourceforge.net
Source0:        http://downloads.sourceforge.net/project/gnome-subtitles/gnome-subtitles/1.3/%{name}-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  gconf-sharp2
BuildRequires:  gconf2-devel
BuildRequires:  glade-sharp2
BuildRequires:  gnome-doc-utils-devel
BuildRequires:  gstreamer-devel
BuildRequires:  gstreamer-plugins-base-devel
BuildRequires:  gtk-sharp2
BuildRequires:  gtk3-devel
BuildRequires:  gtkspell
BuildRequires:  intltool
BuildRequires:  mono-devel
BuildRequires:  translation-update-upstream
BuildRequires:  update-desktop-files
Requires:       glade-sharp2
Requires:       gnome-sharp2
Requires:       gstreamer-plugins-base
Requires:       gtkspell
Requires:       mono-core
Recommends:     %{name}-lang

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%gconf_schemas_prereq

%description
Gnome Subtitles is a subtitle editor for the GNOME desktop. It supports
the most common text-based subtitle formats and allows for subtitle
editing, translation and synchronization.

%lang_package
%prep
%setup -q
translation-update-upstream

%build
%{configure} --disable-scrollkeeper \
   --disable-schemas-install
# Disable parallel build - mono fails to often with it
make

%install
%{makeinstall}
%{__rm} %{buildroot}%{_libdir}/%{name}/libgstreamer_playbin.la
%suse_update_desktop_file %{name}
%find_lang %{name} %{?no_lang_C}
%find_gconf_schemas
%fdupes -s %{buildroot}

%clean
%{__rm} -rf '%{buildroot}'

%pre -f %{name}.schemas_pre

%posttrans -f %{name}.schemas_posttrans

%preun -f %{name}.schemas_preun

%post
%desktop_database_post

%postun
%desktop_database_postun

%files -f %{name}.schemas_list
%defattr(-,root,root,-)
%doc AUTHORS ChangeLog COPYING NEWS README
%dir %{_datadir}/gnome/
%dir %{_datadir}/gnome/help/
%dir %{_datadir}/gnome/help/%{name}/
%doc %{_datadir}/gnome/help/%{name}/C/
%dir %{_datadir}/omf/
%dir %{_datadir}/omf/%{name}/
%doc %{_datadir}/omf/%{name}/%{name}-C.omf
%{_bindir}/%{name}
%{_libdir}/%{name}/
%{_datadir}/applications/%{name}.desktop
%{_mandir}/man1/gnome-subtitles.1*
%{_datadir}/pixmaps/gnome-subtitles.svg

%files lang -f %{name}.lang

%changelog
* Wed Apr  3 2013 dimstar@opensuse.org
- Update to version 1.3:
  + Allow to set the gap between subtitles, to be used when
    inserting or splitting subtitles.
  + Fixed character count when editing text.
  + Multiple subtitle engine fixes.
  + Switched to GStreamer 1.0.
  + Fixed Help menu items.
  + Bugs fixed: bgo#643389, bgo#671567, bgo#659524, bgo#673126,
    bgo#694818, bgo#621475.
  + Updated translations.
- Replace BuildRequires for GStreamer 1.0 port:
  + Old: gstreamer-0_10-devel, gstreamer-0_10-plugins-base-devel,
    gtk2-devel.
  + New: gstreamer-devel, gstreamer-plugins-base-devel, gtk2-devel.
- Replace gstreamer-0_10-plugins-base Requires with
  gstreamer-plugins-base.
- Disable parallel build, as there are random build failures
  observed.
* Tue Aug 23 2011 dimstar@opensuse.org
- Update to version 1.2:
  + Support for merging and splitting subtitle lines
  + Allow to view character counts in the subtitle list and editing
    area
  + Allow to apply a reaction delay when timing start/end on video
    playblack
  + Video slow and fast motion options
  + New shortcuts for quick timings change:
  - Increase/decrease subtitle start time: Ctrl+Plus/Minus
  - Increase/decrease subtitle end time: Alt+Plus/Minus
  - Shift subtitles: Shift+Plus/Minus
  + Automatically seek the video when subtitle times are changed,
    with an option to rewind it some milliseconds
  + Added support for the Fab Subtitler subtitle format
  + Allow to insert a new subtitle at the current video position,
    applying a reaction delay if set
  + Other changes:
  - Translation filenames are now based on the original filename
    plus language
  - Added support for buggy SubRip files that use dots instead of
    commas
  - Fixed bug with the subtitle overlay not being updated on
    times change
  - Detect when selecting a video file as the subtitle file
  - Updated preferences dialog with different structure and more
    options
  - Fixed special characters (<,>,&,etc) not being shown in the
    subtitle list
  + Bugs fixed: bgo#453469, bgo#607227, bgo#607228, bgo#607229,
    bgo#620776, bgo#621145, bgo#621943, bgo#625485, bgo#634230,
    bgo#636766, bgo#636767, bgo#638238, bgo#638484, bgo#642674,
    bgo#648461, bgo#651958
  + Updated translations.
- Drop patches:
  + gnome-subtitles-desktop-entry.patch: fixed upstream.
  + gnome-subtitles-module.patch: fixed upstream.
* Mon Feb 14 2011 sbrabec@suse.cz
- Added support for translation-update-upstream.
* Sat Feb 12 2011 vuntz@opensuse.org
- Call relevant macros in %%post/%%postun:
  + %%desktop_database_post/postun because the package ships at
    least one desktop file.
- Pass %%{?no_lang_C} to %%find_lang so that english documentation
  can be packaged with the program, and not in the lang subpackage.
* Wed Dec  8 2010 vuntz@opensuse.org
- Improve description.
- Change mono Requires to mono-core.
- Add mention of upstream bug numbers for the patches.
- Simplify gnome-subtitles-desktop-entry.patch: the change in the
  Categories key does nothing.
* Thu Nov 11 2010 badshah400@gmail.com
- Initial build (version 1.1)
